@@ -3,4 +3,6 @@ from .utils import *
 from .augmentation import *
 from .blocks import *
 from .callbacks import *
+from .nlp import *
+from .gis import *
 from ._version import __version__
