@@ -36,9 +36,9 @@ def b64_to_img(image_string: str) -> np.ndarray:
 
 def ndarray_to_b64(array: np.ndarray,
                    dtype: Union[None, str] = None,
-                   append_shape=True,
-                   append_dtype=True,
-                   utf_8_decode=True,
+                   append_shape=False,
+                   append_dtype=False,
+                   decode=None,
                    logger: Union[None, logging.Logger] = None):
     """
     Converting a ndarray to base64. For images use "img_to_b64"
@@ -56,7 +56,7 @@ def ndarray_to_b64(array: np.ndarray,
     if isinstance(dtype, str):
         dtype_name = dtype
     else:
-        dtype_name = dtype.name      
+        dtype_name = dtype.name
     dtype_bytes = base64.struct.pack(f">6sI{len(dtype_name)}s", bytes("dtype:", "utf-8"), len(dtype_name),
                                      bytes(dtype_name, "utf-8"))
     if not append_dtype and not append_dtype:
@@ -70,43 +70,48 @@ def ndarray_to_b64(array: np.ndarray,
     else:
         value_error_log(logger, f"dtype: {dtype}, shape: {shape} is not supported")
 
-    if utf_8_decode:
-        res = res.decode("utf-8")
+    if decode:
+        res = res.decode(decode)
 
     return res
 
 
-def b64_to_ndarray(byte_array, dtype=None, shape=None, logger: Union[None, logging.Logger] = None, encdoe=True):
+def b64_to_ndarray(byte_array, dtype, shape, logger: Union[None, logging.Logger] = None, encode=None):
     """
     Converting a base64 to ndarray. For images use "b64_to_img"
     :param byte_array:
-    :param dtype:
-    :param shape:
-    :param logger:
+    :param dtype: pass None if dtype is encoded in the byte_array
+    :param shape: pass None if shape is encoded in the byte_array
+    :param logger: logger instance
+    :param encode: whether encode param or not!
     :return:
     """
     import struct
     import base64
 
-    if encdoe:
-        byte_array = byte_array.encode('utf-8')
+    if encode:
+        byte_array = byte_array.encode(encode)
 
-    if byte_array[:6].decode('utf-8') == "dtype:":
+    if dtype is None and byte_array[:6].decode('utf-8') == "dtype:":
         dtype_len = struct.unpack(">I", byte_array[6: 10])[0]
         dtype = byte_array[10:dtype_len + 10].decode("utf-8")
         byte_array = byte_array[dtype_len + 10:]
     elif dtype is None:
         dtype = np.float32
         log_print(logger, f"dtype is not defined in byte_array nor as an input, setting dtype to {dtype}")
+    elif isinstance(dtype, str):
+        pass
     else:
         value_error_log(logger, f"dtype: {dtype} is not supported!")
 
-    if byte_array[:6].decode('utf-8') == "shape:":
+    if shape is None and byte_array[:6].decode('utf-8') == "shape:":
         shape_len = struct.unpack(">I", byte_array[6: 10])[0]
         shape = struct.unpack(f">{shape_len // 4}I", byte_array[10:10 + shape_len])
         byte_array = byte_array[shape_len + 10:]
     elif shape is None:
         log_print(logger, f"shape is not defined in byte_array nor as input")
+    elif isinstance(shape, tuple):
+        pass
     else:
         value_error_log(logger, f"shape: {shape} is not supported!")
 
@@ -115,9 +120,8 @@ def b64_to_ndarray(byte_array, dtype=None, shape=None, logger: Union[None, loggi
         ndarray = ndarray.reshape(shape)
     return ndarray
 
-
 # if __name__ == '__main__':
 #     array = np.random.random((20, 5)).astype(np.float32)
-#     res = ndarray_to_b64(array)
-#     new_array = b64_to_ndarray(res)
-#     np.all(array == new_array)
+#     res = ndarray_to_b64(array, decode='utf-8')
+#     new_array = b64_to_ndarray(res, dtype='float32', shape=(20, 5), encode='utf-8')
+#     print(np.all(array == new_array))
